searchData={"items":[{"type":"module","doc":"NLdoc Validation is a library that provides accessibility validation for NLdoc documents.\nTODO: proper description","title":"NLdoc.Validation","ref":"NLdoc.Validation.html"},{"type":"function","doc":"","title":"NLdoc.Validation.validate/1","ref":"NLdoc.Validation.html#validate/1"},{"type":"function","doc":"","title":"NLdoc.Validation.validate/2","ref":"NLdoc.Validation.html#validate/2"},{"type":"behaviour","doc":"This module provides a macro for defining validation rules for NLdoc spec objects, i.e. documents and their elements.\nSuch rules check for semantic correctness and accessibility concerns in the spec objects.\n\nSimply `use NLdoc.Validation.Rule` in your module with all details about the validation rule and implement the `valid?/1`\nfunction to determine whether the spec objects that this rule validates, are valid.\n\nYou may also choose to override the `validates/0` and `make_validation/1` functions for more granular control over the\nvalidation process.\n\nIf your validation rule requires state to be maintained during the validation process, implement an `update_state/2` function\nto update the `NLdoc.Validation.State` struct with the necessary information.\n\nNote that the application of and merging of autofixes to a document as a result of validation is currently not implemented.\n\nExample:\n\n    defmodule NLdoc.Validation.Rules.HeadingLevelValid do\n      use NLdoc.Validation.Rule,\n        severity: NLdoc.Validation.Severity.error(),\n        rule: \"invalid-heading-level\",\n        ruleset: \"https://html.spec.whatwg.org/\",\n        ruleset_version: \"5\",\n        validates: [NLdoc.Spec.Heading]\n\n      @impl true\n      def valid?(%NLdoc.Spec.Heading{level: level}, _),\n        do: level >= 1 and level <= 6\n    end","title":"NLdoc.Validation.Rule","ref":"NLdoc.Validation.Rule.html"},{"type":"callback","doc":"","title":"NLdoc.Validation.Rule.make_validation/1","ref":"NLdoc.Validation.Rule.html#c:make_validation/1"},{"type":"type","doc":"","title":"NLdoc.Validation.Rule.opt/0","ref":"NLdoc.Validation.Rule.html#t:opt/0"},{"type":"type","doc":"","title":"NLdoc.Validation.Rule.t/0","ref":"NLdoc.Validation.Rule.html#t:t/0"},{"type":"callback","doc":"","title":"NLdoc.Validation.Rule.update_state/2","ref":"NLdoc.Validation.Rule.html#c:update_state/2"},{"type":"callback","doc":"","title":"NLdoc.Validation.Rule.valid?/2","ref":"NLdoc.Validation.Rule.html#c:valid?/2"},{"type":"callback","doc":"","title":"NLdoc.Validation.Rule.validate/2","ref":"NLdoc.Validation.Rule.html#c:validate/2"},{"type":"callback","doc":"","title":"NLdoc.Validation.Rule.validates/0","ref":"NLdoc.Validation.Rule.html#c:validates/0"},{"type":"module","doc":"This rule validates that the a definition list has at least one definition term.","title":"NLdoc.Validation.Rules.DefinitionListHasDefinitionTerm","ref":"NLdoc.Validation.Rules.DefinitionListHasDefinitionTerm.html"},{"type":"function","doc":"","title":"NLdoc.Validation.Rules.DefinitionListHasDefinitionTerm.has_definition_term?/1","ref":"NLdoc.Validation.Rules.DefinitionListHasDefinitionTerm.html#has_definition_term?/1"},{"type":"module","doc":"This rule validates that each DefinitionTerm in a DefinitionList is followed by a DefinitionDetails.","title":"NLdoc.Validation.Rules.DefinitionTermHasDefinitionDetails","ref":"NLdoc.Validation.Rules.DefinitionTermHasDefinitionDetails.html"},{"type":"module","doc":"This rule validates that definition details must always contain discernible text.","title":"NLdoc.Validation.Rules.EmptyDefinitionDetails","ref":"NLdoc.Validation.Rules.EmptyDefinitionDetails.html"},{"type":"module","doc":"This rule validates that a definition term must always contain discernible text.","title":"NLdoc.Validation.Rules.EmptyDefinitionTerm","ref":"NLdoc.Validation.Rules.EmptyDefinitionTerm.html"},{"type":"module","doc":"This rule validates that a heading must always contain discernible text.","title":"NLdoc.Validation.Rules.EmptyHeading","ref":"NLdoc.Validation.Rules.EmptyHeading.html"},{"type":"module","doc":"This rule validates that a table header must always contain discernible text.","title":"NLdoc.Validation.Rules.EmptyTableHeader","ref":"NLdoc.Validation.Rules.EmptyTableHeader.html"},{"type":"module","doc":"This rule validates that a heading's level is valid according to the HTML spec (i.e. between 1 and 6).","title":"NLdoc.Validation.Rules.HeadingLevelValid","ref":"NLdoc.Validation.Rules.HeadingLevelValid.html"},{"type":"module","doc":"This rule validates that headings are ordered sequentially-descending,\ni.e. heading levels should only increase by one, but may decrease by any.","title":"NLdoc.Validation.Rules.HeadingOrder","ref":"NLdoc.Validation.Rules.HeadingOrder.html"},{"type":"module","doc":"This rule validates that an image has an alternative text, or is marked as decorative.","title":"NLdoc.Validation.Rules.ImageMustHaveAlt","ref":"NLdoc.Validation.Rules.ImageMustHaveAlt.html"},{"type":"module","doc":"This rule validates that a link must always contain discernible text.","title":"NLdoc.Validation.Rules.LinkName","ref":"NLdoc.Validation.Rules.LinkName.html"},{"type":"module","doc":"This rule validates that the style underline was not used on a Text.","title":"NLdoc.Validation.Rules.NoUnderline","ref":"NLdoc.Validation.Rules.NoUnderline.html"},{"type":"module","doc":"This rule validates that a document has at least one heading level 1.","title":"NLdoc.Validation.Rules.PageHasHeadingOne","ref":"NLdoc.Validation.Rules.PageHasHeadingOne.html"},{"type":"module","doc":"This rule validates that the document has only one Heading with level 1.","title":"NLdoc.Validation.Rules.PageHasMultipleHeadingOne","ref":"NLdoc.Validation.Rules.PageHasMultipleHeadingOne.html"},{"type":"module","doc":"This rule validates that a document starts with a Heading with level 1.\nIt produces a validation finding on the first heading with level 1 found in the document,\nif it is not the first element in the document.\n\nNote: this rule will *not* produce a validation finding if the document does not contain a heading with level 1.","title":"NLdoc.Validation.Rules.PageStartsWithHeadingOne","ref":"NLdoc.Validation.Rules.PageStartsWithHeadingOne.html"},{"type":"module","doc":"This rule validates that tables have more than one row.","title":"NLdoc.Validation.Rules.TableNeedsMultipleRows","ref":"NLdoc.Validation.Rules.TableNeedsMultipleRows.html"},{"type":"module","doc":"Severity levels for validation rules.","title":"NLdoc.Validation.Severity","ref":"NLdoc.Validation.Severity.html"},{"type":"function","doc":"","title":"NLdoc.Validation.Severity.error/0","ref":"NLdoc.Validation.Severity.html#error/0"},{"type":"function","doc":"","title":"NLdoc.Validation.Severity.notice/0","ref":"NLdoc.Validation.Severity.html#notice/0"},{"type":"type","doc":"","title":"NLdoc.Validation.Severity.t/0","ref":"NLdoc.Validation.Severity.html#t:t/0"},{"type":"function","doc":"","title":"NLdoc.Validation.Severity.values/0","ref":"NLdoc.Validation.Severity.html#values/0"},{"type":"function","doc":"","title":"NLdoc.Validation.Severity.warning/0","ref":"NLdoc.Validation.Severity.html#warning/0"},{"type":"module","doc":"State for validation rules.","title":"NLdoc.Validation.State","ref":"NLdoc.Validation.State.html"},{"type":"function","doc":"Gets the given field from the state object.\n\nThis function only accepts fields of the state, which are :findings, :heading_level, :definition_term_id_without_details, :encountered_heading_1?.\nIt will raise if the field is not valid.","title":"NLdoc.Validation.State.get/2","ref":"NLdoc.Validation.State.html#get/2"},{"type":"function","doc":"Modifies a state object by setting the given field to the value that field had in the old state.\n\nThis function only accepts fields of the state, which are :findings, :heading_level, :definition_term_id_without_details, :encountered_heading_1?.\nIt will raise if the field is not valid.","title":"NLdoc.Validation.State.keep/3","ref":"NLdoc.Validation.State.html#keep/3"},{"type":"function","doc":"Prepends a list of values or a single value to the list field in the state object.\n\nThis function only accepts fields of the state, which are :findings.\nIt will raise if the field is not valid.","title":"NLdoc.Validation.State.prepend/3","ref":"NLdoc.Validation.State.html#prepend/3"},{"type":"function","doc":"Sets the given field on the state object to the given value.\n\nThis function only accepts fields of the state, which are :findings, :heading_level, :definition_term_id_without_details, :encountered_heading_1?.\nIt will raise if the field is not valid.","title":"NLdoc.Validation.State.set/3","ref":"NLdoc.Validation.State.html#set/3"},{"type":"type","doc":"","title":"NLdoc.Validation.State.t/0","ref":"NLdoc.Validation.State.html#t:t/0"},{"type":"extras","doc":"# NLdoc.Validation","title":"NLdoc.Validation","ref":"readme.html"},{"type":"extras","doc":"The package can be installed by adding `nldoc_validation` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nldoc_validation, \"~> 1.0.0\"}\n  ]\nend\n```\n\nDocumentation can be found at  .","title":"Installation - NLdoc.Validation","ref":"readme.html#installation"},{"type":"extras","doc":"# Changelog\n\n## [2.0.5](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/compare/2.0.4...2.0.5) (2025-02-22)","title":"Changelog","ref":"changelog.html"},{"type":"extras","doc":"* **deps:** update dependency nldoc_spec to v1.2.4 ([29f9c1c](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/29f9c1c51815a1ec08d45bc7dafdddb074f4e19d))\n* **deps:** update dependency nldoc_test to v3.0.2 ([fa83cd9](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/fa83cd98c9c5c97247c80d90a5e5bc90aa2e9fee))\n\n## [2.0.4](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/compare/2.0.3...2.0.4) (2025-02-20)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* **deps:** update dependency ex_doc to v0.37.2 ([d49d3c6](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/d49d3c65cf69ce9910d450ddf1247ae17d6a5834))\n\n## [2.0.3](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/compare/2.0.2...2.0.3) (2025-02-14)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* **deps:** update dependency nldoc_spec to v1.2.3 ([107603a](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/107603a9139db42636d8bcf7fdf37e11abbdfaf6))\n\n## [2.0.2](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/compare/2.0.1...2.0.2) (2025-02-13)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* **deps:** update dependency ex_doc to ~> 0.37 ([afa8b7e](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/afa8b7e55b81766e618bd7d4e1aee268bb6e0f48))\n* **deps:** update dependency nldoc_test to v3.0.1 ([7f79464](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/7f7946437dca139f46bfe1a9a61af7b564725e9a))\n\n## [2.0.1](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/compare/2.0.0...2.0.1) (2025-02-12)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* **deps:** update dependency nldoc_spec to v1.2.1 ([fa176eb](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/fa176ebca8d9f551640a2e6f1573ac70347bc161))\n\n# [2.0.0](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/compare/1.0.2...2.0.0) (2025-02-06)\n\n\n* feat!: remove NLdoc.Validation.Content ([9d35dbe](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/9d35dbe13bbe83ee7ea63501a846cefc3bde1b9e))","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* this remove NLdoc.Validation.Content, please use NLdoc.Spec.Content instead.\n\n## [1.0.2](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/compare/1.0.1...1.0.2) (2025-01-28)","title":"BREAKING CHANGES - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"* **deps:** update dependency nldoc_spec to v1.1.2 ([bc4fe0d](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/bc4fe0da96e5e3ae7f1d2c5764ea50d4164d9d51))\n\n## [1.0.1](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/compare/1.0.0...1.0.1) (2025-01-28)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* **deps:** update dependency excoveralls to v0.18.5 ([1ab4873](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/1ab48731fd70fb34be6d4d10a1fb1e114551c06e))\n* **deps:** update dependency nldoc_spec to v1.1.1 ([eb367b2](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/eb367b2414dd86d76b48e452fa29774624229c3f))\n\n# 1.0.0 (2025-01-23)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* **NLD-586:** NLdoc.Validation initial commit ([8b34338](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/8b34338c9e8aa5ca0084849e9984ad033e244656))\n\n# 1.0.0 (2025-01-23)","title":"Features - Changelog","ref":"changelog.html#features"},{"type":"extras","doc":"* **NLD-586:** package name ([5154b11](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_logging/commit/5154b1140e4f2b2fd3d204025efed0459bae7aed))","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* **NLD-586:** package logger ([708895d](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_logging/commit/708895da7ca240dbde4b88420a0e40d14f55394e))","title":"Features - Changelog","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}